pywurfl.algorithms.wurfl

Package pywurfl :: Package algorithms :: Package wurfl |
[hide private]
[frames] | no frames]

# Package wurfl

source code

Submodules | [hide private]
pywurfl.algorithms.wurfl.handlers: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL. pywurfl.algorithms.wurfl.normalizers: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL. pywurfl.algorithms.wurfl.strategies: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL. pywurfl.algorithms.wurfl.utils: This module contains the supporting classes for the Two Step Analysis user agent algorithm that is used as the primary way to match user agents with the Java API for the WURFL.

Variables | [hide private]
| __package__ = `None`